all messages for Guix-related lists mirrored at yhetil.org
 help / color / mirror / code / Atom feed
* [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2.
@ 2023-03-31 22:46 Theofilos Pechlivanis
  2023-04-01  8:39 ` 宋文武 via Guix-patches via
  2023-04-01 12:19 ` [bug#62582] [PATCH v2] " Theofilos Pechlivanis
  0 siblings, 2 replies; 4+ messages in thread
From: Theofilos Pechlivanis @ 2023-03-31 22:46 UTC (permalink / raw)
  To: 62582; +Cc: Theofilos Pechlivanis

---
 gnu/packages/engineering.scm | 71 ++++++++++++++++++++++--------------
 1 file changed, 43 insertions(+), 28 deletions(-)

-- 
2.39.2





^ permalink raw reply related	[flat|nested] 4+ messages in thread

* [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2.
  2023-03-31 22:46 [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2 Theofilos Pechlivanis
@ 2023-04-01  8:39 ` 宋文武 via Guix-patches via
  2023-04-01 12:19 ` [bug#62582] [PATCH v2] " Theofilos Pechlivanis
  1 sibling, 0 replies; 4+ messages in thread
From: 宋文武 via Guix-patches via @ 2023-04-01  8:39 UTC (permalink / raw)
  To: Theofilos Pechlivanis; +Cc: 62582

Theofilos Pechlivanis <theofilos.pechlivanis@gmail.com> writes:

> ---
>  gnu/packages/engineering.scm | 71 ++++++++++++++++++++++--------------
>  1 file changed, 43 insertions(+), 28 deletions(-)

Hello, there should also be files changes (for update, arguments and
inputs) description in commit message.

> +     (list #:configure-flags #~(list "-Dpackager=guix"
> +                                     (string-append "-Dpackager_version="
> +                                                    #$version)
> +                                     "-Duse_sys_capstone=enabled"

Please keep the original indention, so we can easily see what changes in
this new patch.

> +                            ;; Also skip unit tests for the same reason.
> +                            (substitute* "test/meson.build"
> +                              (("subdir\\('integration'\\)")
> +                               "")
> +                              (("subdir\\('unit'\\)")
> +                               "")))))))

Um, does all the unit tests also require testbins now?  If there are
few unit tests require testbins, I think it better to patch them out
instead of skip all tests.


Could you send an update patch, thank you!




^ permalink raw reply	[flat|nested] 4+ messages in thread

* [bug#62582] [PATCH v2] gnu: rizin: Update to 0.5.2.
  2023-03-31 22:46 [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2 Theofilos Pechlivanis
  2023-04-01  8:39 ` 宋文武 via Guix-patches via
@ 2023-04-01 12:19 ` Theofilos Pechlivanis
  2023-04-06 15:48   ` bug#62582: [PATCH] " Ludovic Courtès
  1 sibling, 1 reply; 4+ messages in thread
From: Theofilos Pechlivanis @ 2023-04-01 12:19 UTC (permalink / raw)
  To: 62582; +Cc: Theofilos Pechlivanis

* gnu/packages/engineering.scm (rizin): Update to 0.5.2.
[arguments]: Remove libuv. Add lzma, libmspack and swift_demangler. Skip the analysis_var test.
[inputs]: Add libmspack.
---
 gnu/packages/engineering.scm | 19 ++++++++++++++-----
 1 file changed, 14 insertions(+), 5 deletions(-)

diff --git a/gnu/packages/engineering.scm b/gnu/packages/engineering.scm
index 18f2d024b1..37cfce3c03 100644
--- a/gnu/packages/engineering.scm
+++ b/gnu/packages/engineering.scm
@@ -36,6 +36,7 @@
 ;;; Copyright © 2022 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 ;;; Copyright © 2022 Maxim Cournoyer <maxim.cournoyer@gmail.com>
 ;;; Copyright © 2022 Felix Gruber <felgru@posteo.net>
+;;; Copyright © 2023 Theofilos Pechlivanis <theofilos.pechlivanis@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -4094,7 +4095,7 @@ (define-public candle
 (define-public rizin
   (package
     (name "rizin")
-    (version "0.4.1")
+    (version "0.5.2")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -4102,7 +4103,7 @@ (define-public rizin
                     version "/rizin-src-v" version ".tar.xz"))
               (sha256
                (base32
-                "1f5zzlnr2na4hkvcwn4n9cjlk6595945vwrw89pa683qk5mrb7b6"))))
+                "18zca3iwdif200wiivm065fs0a5g520q6380205cijca7ky81avi"))))
     (build-system meson-build-system)
     (arguments
      (list
@@ -4117,7 +4118,12 @@ (define-public rizin
               "-Duse_sys_xxhash=enabled"
               "-Duse_sys_openssl=enabled"
               "-Duse_sys_tree_sitter=enabled"
-              "-Duse_sys_libuv=enabled"
+              "-Duse_sys_lzma=enabled"
+              "-Duse_sys_libmspack=enabled"
+              "-Duse_zlib=true"
+              "-Duse_lzma=true"
+              "-Dinstall_sigdb=false"
+              "-Duse_swift_demangler=true"
               "-Duse_gpl=true")
       #:phases
       #~(modify-phases %standard-phases
@@ -4128,10 +4134,13 @@ (define-public rizin
               ;; And 2 of them are failing, reported upstream:
               ;; <https://github.com/rizinorg/rizin/issues/2905>.
               (substitute* "test/meson.build"
-                (("subdir\\('integration'\\)") "")))))))
+                (("subdir\\('integration'\\)") ""))
+              ;;; Skip analysis_var test, which is failing.
+              (substitute* "test/unit/meson.build"
+                (("'analysis_var',\n") "")))))))
     (native-inputs (list pkg-config))
     (inputs
-     (list capstone file libuv libzip lz4 openssl tree-sitter xxhash zlib))
+     (list capstone file libuv libzip lz4 openssl tree-sitter xxhash zlib libmspack))
     (home-page "https://rizin.re")
     (synopsis "Disasm, debug, analyze and manipulate binary files")
     (description

base-commit: 47ea688fd27d0ce0c8ea5481f1f94d0ebc3e37eb
diff --git a/gnu/packages/engineering.scm b/gnu/packages/engineering.scm
index 18f2d024b1..a0431ed441 100644
--- a/gnu/packages/engineering.scm
+++ b/gnu/packages/engineering.scm
@@ -36,6 +36,7 @@
 ;;; Copyright © 2022 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 ;;; Copyright © 2022 Maxim Cournoyer <maxim.cournoyer@gmail.com>
 ;;; Copyright © 2022 Felix Gruber <felgru@posteo.net>
+;;; Copyright © 2023 Theofilos Pechlivanis <theofilos.pechlivanis@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -4094,7 +4095,7 @@ (define-public candle
 (define-public rizin
   (package
     (name "rizin")
-    (version "0.4.1")
+    (version "0.5.2")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -4102,36 +4103,50 @@ (define-public rizin
                     version "/rizin-src-v" version ".tar.xz"))
               (sha256
                (base32
-                "1f5zzlnr2na4hkvcwn4n9cjlk6595945vwrw89pa683qk5mrb7b6"))))
+                "18zca3iwdif200wiivm065fs0a5g520q6380205cijca7ky81avi"))))
     (build-system meson-build-system)
     (arguments
-     (list
-      #:configure-flags
-      #~(list "-Dpackager=guix"
-              (string-append "-Dpackager_version=" #$version)
-              "-Duse_sys_capstone=enabled"
-              "-Duse_sys_magic=enabled"
-              "-Duse_sys_libzip=enabled"
-              "-Duse_sys_zlib=enabled"
-              "-Duse_sys_lz4=enabled"
-              "-Duse_sys_xxhash=enabled"
-              "-Duse_sys_openssl=enabled"
-              "-Duse_sys_tree_sitter=enabled"
-              "-Duse_sys_libuv=enabled"
-              "-Duse_gpl=true")
-      #:phases
-      #~(modify-phases %standard-phases
-          (add-before 'configure 'skip-integration-tests
-            (lambda _
-              ;; Skip integration tests, which require prebuilt binaries at:
-              ;; <https://github.com/rizinorg/rizin-testbins>.
-              ;; And 2 of them are failing, reported upstream:
-              ;; <https://github.com/rizinorg/rizin/issues/2905>.
-              (substitute* "test/meson.build"
-                (("subdir\\('integration'\\)") "")))))))
+     (list #:configure-flags #~(list "-Dpackager=guix"
+                                     (string-append "-Dpackager_version="
+                                                    #$version)
+                                     "-Duse_sys_capstone=enabled"
+                                     "-Duse_sys_magic=enabled"
+                                     "-Duse_sys_libzip=enabled"
+                                     "-Duse_sys_zlib=enabled"
+                                     "-Duse_sys_lz4=enabled"
+                                     "-Duse_sys_lzma=enabled"
+                                     "-Duse_sys_xxhash=enabled"
+                                     "-Duse_sys_openssl=enabled"
+                                     "-Duse_sys_tree_sitter=enabled"
+                                     "-Duse_sys_libmspack=enabled"
+                                     "-Duse_gpl=true"
+                                     "-Duse_zlib=true"
+                                     "-Duse_lzma=true"
+                                     "-Dinstall_sigdb=false"
+                                     "-Duse_swift_demangler=true")
+           #:phases #~(modify-phases %standard-phases
+                        (add-before 'configure 'skip-integration-tests
+                          (lambda _
+                            ;; Skip integration tests, which require prebuilt binaries at:
+                            ;; <https://github.com/rizinorg/rizin-testbins>.
+                            ;; And 2 of them are failing, reported upstream:
+                            ;; <https://github.com/rizinorg/rizin/issues/2905>.
+                            ;; Also skip unit tests for the same reason.
+                            (substitute* "test/meson.build"
+                              (("subdir\\('integration'\\)")
+                               "")
+                              (("subdir\\('unit'\\)")
+                               "")))))))
     (native-inputs (list pkg-config))
-    (inputs
-     (list capstone file libuv libzip lz4 openssl tree-sitter xxhash zlib))
+    (inputs (list capstone
+                  file
+                  libzip
+                  lz4
+                  openssl
+                  tree-sitter
+                  xxhash
+                  zlib
+                  libmspack))
     (home-page "https://rizin.re")
     (synopsis "Disasm, debug, analyze and manipulate binary files")
     (description

base-commit: 47ea688fd27d0ce0c8ea5481f1f94d0ebc3e37eb
-- 
2.39.2





^ permalink raw reply related	[flat|nested] 4+ messages in thread

* bug#62582: [PATCH] gnu: rizin: Update to 0.5.2.
  2023-04-01 12:19 ` [bug#62582] [PATCH v2] " Theofilos Pechlivanis
@ 2023-04-06 15:48   ` Ludovic Courtès
  0 siblings, 0 replies; 4+ messages in thread
From: Ludovic Courtès @ 2023-04-06 15:48 UTC (permalink / raw)
  To: Theofilos Pechlivanis; +Cc: 62582-done

Hi,

Theofilos Pechlivanis <theofilos.pechlivanis@gmail.com> skribis:

> * gnu/packages/engineering.scm (rizin): Update to 0.5.2.
> [arguments]: Remove libuv. Add lzma, libmspack and swift_demangler. Skip the analysis_var test.
> [inputs]: Add libmspack.

Applied, thanks!

Ludo’.




^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2023-04-06 15:49 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2023-03-31 22:46 [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2 Theofilos Pechlivanis
2023-04-01  8:39 ` 宋文武 via Guix-patches via
2023-04-01 12:19 ` [bug#62582] [PATCH v2] " Theofilos Pechlivanis
2023-04-06 15:48   ` bug#62582: [PATCH] " Ludovic Courtès

Code repositories for project(s) associated with this external index

	https://git.savannah.gnu.org/cgit/guix.git

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.